<?php

namespace Drupal\health_check_url\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\PageCache\ResponsePolicy\KillSwitch;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for route that returns health check url type.
 */
class HealthCheckController extends ControllerBase {

  /**
   * The page cache kill switch.
   *
   * @var \Drupal\Core\PageCache\ResponsePolicy\KillSwitch
   */
  protected $killSwitch;

  protected $string;

  /**
   * Constructs a new HealthCheckController object.
   *
   * @param \Drupal\Core\PageCache\ResponsePolicy\KillSwitch $kill_switch
   *   The page cache kill switch.
   */
  public function __construct(KillSwitch $kill_switch) {
    $this->killSwitch = $kill_switch;
    $config = \Drupal::config('health_check_url.settings');
    $this->string = $config->get('string') != "" ? $config->get('string') : "Passed";
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('page_cache_kill_switch')
    );
  }

  /**
   * timestamp health check
   *
   * @return \Symfony\Component\HttpFoundation\Response
   */
  public function timestamp() {
    // Disable page cache
    $this->killSwitch->trigger();

    // Use plain response with timestamp
    $response = new Response();
    $response->setContent(time());

    return $response;
  }

  /**
   * string check
   *
   * @return array
   */
  public function string() {
    // Disable page cache
    $this->killSwitch->trigger();

    $response = new Response();
    
    $response->setContent($this->string);

    return $response;
  }

  /**
   * string with date time timestamp check
   *
   * @return array
   */
  public function stringWithDateTimestamp() {
    // Disable page cache
    $this->killSwitch->trigger();

    $response = new Response();
    $response->setContent($this->string.' ' . strftime("at %T on %D") . ' (' . time() . ')');

    return $response;
  }

  /**
   * string with timestamp check
   *
   * @return array
   */
  public function stringWithTimestamp() {
    // Disable page cache
    $this->killSwitch->trigger();

    $response = new Response();
    $response->setContent($this->string.' - ' . time());

    return $response;
  }

  /**
   * string with date time timestamp check
   *
   * @return array
   */
  public function stringWithDateTime() {
    // Disable page cache
    $this->killSwitch->trigger();

    $response = new Response();
    $response->setContent($this->string.' ' . strftime("at %T on %D"));

    return $response;
  }

}
